An example map to show landscapetools functionality generated with the `nlm_randomcluster()` algorithm and coerced to vector data (multipolygon).
An example map to show landscapetools functionality generated with the `nlm_randomcluster()` algorithm and coerced to vector data (multipolygon).