The mean value of core area index at class level(vector data)
Source:R/vm_c_cai_mn.R
vm_c_cai_mn.RdThis function allows you to calculate the mean value of ratio of the core area and the area belonging to one class in a categorical landscape in vector data format
Value
the returned calculated mean value of core area index of each class is in column "value", and this function returns also some important information such as level, class number and metric name. Moreover, the "id" column, although it is just NA here at class level. we need it because the output struture of metrics at class level should correspond to patch level one by one, and then it is more convinient to combine metric values at different levels and compare them.