The coefficient of variation of number of disjunct core areas in each class (vector data)
Source:R/vm_c_dcore_cv.R
vm_c_dcore_cv.RdThis function allows you to calculate the coefficient of variation of each class belonging to one class in a categorical landscape in vector data format
Value
the returned calculated coefficient of variation in each class is in column "value", and this function returns also some important information such as level, class number and metric name. Moreover, the "id" column, although it is just NA here at class level. we need it because the output struture of metrics at class level should correspond to patch level one by one, and then it is more convinient to combine metric values at different levels and compare them.