The standard deviation of Euclidean Nearest-Neighbor Distance of patches in each class(vector data)
Source:R/vm_c_enn_sd.R
vm_c_enn_sd.RdThis function allows you to calculate the standard deviation of Euclidean Nearest-Neighbor Distance among patches of one class in a categorical landscape in vector data format
Value
the returned calculated standard deviation of each class is in column "value", and this function returns also some important information such as level, class number and metric name. Moreover, the "id" column, although it is just NA here at class level. we need it because the output struture of metrics at class level should correspond to patch level one by one, and then it is more convinient to combine metric values at different levels and compare them.