The standard deviation of the fractal dimension index of all patches in each class(vector data)
Source:R/vm_c_frac_sd.R
vm_c_frac_sd.RdThis function allows you to calculate the standard deviation of fractal dimension index of all patches belonging to class i in a categorical landscape in vector data format The index is based on the patch perimeter and the patch area and describes the patch complexity
Value
the returned calculated standard deviation of each class is in column "value", and this function returns also some important information such as level, class number and metric name. Moreover, the "id" column, although it is just NA here at class level. we need it because the output struture of metrics at class level should correspond to patch level one by one, and then it is more convinient to combine metric values at different levels and compare them.