Calculate Proximity Index
Value
the function returns tibble with the calculated values in column "value", this function returns also some important information such as level, class, patch id and metric name. vm_c_proxim_mn(vector_landscape, "class")
Calculate Proximity Index
the function returns tibble with the calculated values in column "value", this function returns also some important information such as level, class, patch id and metric name. vm_c_proxim_mn(vector_landscape, "class")