This function allows you to calculate the total core area of each class in a categorical landscape in vector data format
Value
the returned calculated total class core areas are in column "value", and this function returns also some important information such as level, class number and metric name. Moreover, the "id" column, although it is just NA here at class level. we need it because the output struture of metrics at class level should correspond to patch level one by one, and then it is more convinient to combine metric values at different levels and compare them.