This function helps to analyse the patch structure the calculate process is, each patch is squared before the sums of them are calculated and the sum is standardized by the total landscape area. it is a aggregation metric.
This function helps to analyse the patch structure the calculate process is, each patch is squared before the sums of them are calculated and the sum is standardized by the total landscape area. it is a aggregation metric.