the number of disjunct core area in the whole landscape(vector data)
Source:R/vm_l_ndca.R
vm_l_ndca.RdThis function allows you to calculate the number of disjunct core areas in a categorical landscape in vector data format
R/vm_l_ndca.R
vm_l_ndca.RdThis function allows you to calculate the number of disjunct core areas in a categorical landscape in vector data format