This function allows you to calculate the Shannons's evenness index
in a categorical landscape in vector data format, Shannons's evenness index is diversity index
It is the ratio between the actual Shannon's diversity index and and the theoretical maximum of the Shannon diversity index
Usage
vm_l_shei(landscape, class_col)
Arguments
- landscape
the input landscape image,
- class_col
the name of the class column of the input landscape
Value
the returned calculated index is in column "value",
and this function returns also some important information such as level and metric name,
Moreover, class number and the "id" column, although both are "NA" here in the landscape level
Examples
vm_l_shei(vector_landscape, "class")
#> # A tibble: 1 × 5
#> level class id metric value
#> <chr> <chr> <chr> <chr> <dbl>
#> 1 landscape NA NA shei 0.924