Solidity convexity
Value
the function returns tibble with the calculated values in column "value", this function returns also some important information such as level, class, patch id and metric name.
Solidity convexity
the function returns tibble with the calculated values in column "value", this function returns also some important information such as level, class, patch id and metric name.