Usage
vm_p_convex(landscape, class_col = NULL, patch_col = NULL)
Arguments
- landscape
the input landscape image,
- class_col
the name of the class column of the input landscape
- patch_col
the name of the id column of the input landscape
Value
the function returns tibble with the calculated values in column "value",
this function returns also some important information such as level, class, patch id and metric name.
Details
ratio between perimeter of convex hull and perimeter of polygon
References
Jiao, L., Liu, Y., & Li, H. (2012). Characterizing land-use classes in remote sensing imagery by shape metrics.
ISPRS Journal of Photogrammetry and Remote Sensing, 72, 46–55. https://doi.org/10.1016/j.isprsjprs.2012.05.012
Examples
vm_p_convex(vector_landscape, "class")
#> # A tibble: 3 × 5
#> level class id metric value
#> <chr> <chr> <chr> <chr> <dbl>
#> 1 patch 1 1 convex 0.506
#> 2 patch 2 2 convex 0.369
#> 3 patch 3 3 convex 0.325