The mean value of all patch areas at landscape level(vector data)
Source:R/vm_l_area_mn.R
vm_l_area_mn.RdThis function allows you to calculate the mean value of all patch areas in a categorical landscape in vector data format
R/vm_l_area_mn.R
vm_l_area_mn.RdThis function allows you to calculate the mean value of all patch areas in a categorical landscape in vector data format