Calculate form factor or compactness
Value
the function returns tibble with the calculated values in column "value", this function returns also some important information such as level, class, patch id and metric name.
Details
Mean compactness across all patches in the landscape. Compactness is calculated as: $$COMPACT = \frac{4\pi A}{P^2}$$ where \(A\) is the patch area (m²) and \(P\) is the perimeter (m). Values range from 0 (linear) to 1 (circular).