Calculate Roughness index (RI)
Value
the function returns tibble with the calculated values in column "value", this function returns also some important information such as level, class, patch id and metric name.
Details
Mean roughness across all patches in the landscape. Roughness quantifies shape irregularity by measuring the variance in distances from boundary points to the centroid, normalized by area and perimeter. Higher values indicate more irregular, complex boundaries.
References
Basaraner, M., & Cetinkaya, S. (2017). Performance of shape indices and classification schemes for characterising perceptual shape complexity of building footprints in GIS. International Journal of Geographical Information Science, 31(10), 1952–1977. https://doi.org/10.1080/13658816.2017.1346257